@@ -207,14 +207,14 @@ def fetch_resources(node_names: list[str]=None):
         data["node_names"] = node_names
     try:
         total = request_to_server(
-            method="get",
+            method="post",
             endpoint="/v1/get_cluster_total_resources",
             data=data,
             server_creds=USER_LOCAL_SERVER_FILE,
             user_cookie=USER_COOKIE
         )
         available = request_to_server(
-            method="get",
+            method="post",
             endpoint="/v1/get_cluster_available_resources",
             data=data,
             server_creds=USER_LOCAL_SERVER_FILE,
@@ -468,7 +468,7 @@ def fetch_pod_logs(label_key, label_value, force_namespace=None, pod_name=None,
     data = {
         "label": label_key,
         "value": label_value,
-        "tail": tail
+        "tail_lines": tail
     }
     if force_namespace is not None:
         data["force_namespace"] = force_namespace
@@ -476,7 +476,7 @@ def fetch_pod_logs(label_key, label_value, force_namespace=None, pod_name=None,
         # send tail as parameter (fetch only last _tail_ lines)
         all_logs = request_to_server(
             method="post",
-            endpoint="/v1/get_logs_for_label",
+            endpoint="/v1/get_job_details",
             data=data,
             server_creds=USER_LOCAL_SERVER_FILE,
             user_cookie=USER_COOKIE
@@ -672,8 +672,9 @@ def join_pool(
         node_name=None,
         ip_address=None,
         target_platform="amd64",
-        mtu="1420",
-        node_labels={}
+        mtu="",
+        node_labels={},
+        is_seed=False
 ):
     compatibility = check_worker_compatibility()
     if len(compatibility["issues"]) > 0:
@@ -684,9 +685,6 @@ def join_pool(
 
     if node_name is None:
         node_name = socket.gethostname()
-
-    if mtu is None:
-        mtu = "1420"
     
     # check token
     valid = check_token(token=token)
@@ -708,13 +706,13 @@ def join_pool(
     node_labels = {
         **node_labels,
         STORAGE_CLASS_LABEL: is_storage_compatible(),
-        NODE_ROLE_LABEL: "worker"
+        NODE_ROLE_LABEL: "worker" if not is_seed else "server"
     }  
     # local agent join
     # Generate docker compose recipe
     generate_compose_config(
         target_platform=target_platform,
-        role="agent",
+        role="agent" if not is_seed else "seed",
         node_ip_address=ip_address,
         pool_ip=f"https://{kalavai_seed_ip}:6443",
         pool_token=kalavai_token,
@@ -761,20 +759,21 @@ def join_pool(
     return cluster_name
 
 def create_pool(
-        cluster_name: str=None,
-        ip_address: str=None,
-        location: str=None,
-        target_platform: str="amd64",
-        watcher_image_tag: str=None,
-        pool_config_file: str=None,
-        description: str="",
-        token_mode: TokenType=TokenType.USER,
-        num_gpus: int=-1,
-        node_name: str=None,
-        mtu: str=None,
-        apps: list=[],
-        node_labels: dict={}
-    ):
+    cluster_name: str=None,
+    ip_address: str=None,
+    lb_ip_address: str=None,
+    location: str=None,
+    target_platform: str="amd64",
+    watcher_image_tag: str=None,
+    pool_config_file: str=None,
+    description: str="",
+    token_mode: TokenType=TokenType.USER,
+    num_gpus: int=-1,
+    node_name: str=None,
+    mtu: str="",
+    apps: list=[],
+    node_labels: dict={}
+):
 
     if not check_seed_compatibility():
         return {"error": "Requirements failed"}
@@ -806,7 +805,7 @@ def create_pool(
         ip_address = config_values["server"]["ip_address"] if ip_address is None else ip_address
         location = config_values["server"]["location"] if location is None else location
         target_platform = config_values["server"]["platform"] if target_platform is None else target_platform
-        mtu = config_values["server"]["mtu"] if mtu is None else mtu
+        mtu = config_values["server"]["mtu"] if mtu == "" or mtu is None else mtu
         app_values = config_values["core"]
         post_config_values = config_values["pool"]
         deploy_apps = {
@@ -825,10 +824,12 @@ def create_pool(
         role="server",
         vpn_token=location,
         node_ip_address=ip_address,
+        lb_ip_address=lb_ip_address,
         num_gpus=num_gpus,
         node_name=node_name,
         node_labels=node_labels,
-        mtu=mtu
+        mtu=mtu,
+        host_root_path=config_values["server"]["host_root_path"]
     )
 
     # start server
@@ -836,6 +837,7 @@ def create_pool(
     while not CLUSTER.is_agent_running():
         time.sleep(10)
     
+    
     # select IP address (for external discovery)
     if ip_address is None or location is not None:
         # load VPN ip
@@ -851,7 +853,7 @@ def create_pool(
     watcher_service = f"{ip_address}:{DEFAULT_WATCHER_PORT}"
     values = {
         #CLUSTER_NAME_KEY: cluster_name,
-        CLUSTER_IP_KEY: ip_address,
+        CLUSTER_IP_KEY: ip_address if lb_ip_address is None else lb_ip_address,
         USER_ID_KEY: user_id if user_id is not None else "",
         AUTH_KEY: auth_key,
         READONLY_AUTH_KEY: readonly_auth_key,
@@ -864,7 +866,7 @@ def create_pool(
     }
 
     store_server_info(
-        server_ip=ip_address,
+        server_ip=ip_address if lb_ip_address is None else lb_ip_address,
         auth_key=auth_key,
         readonly_auth_key=readonly_auth_key,
         write_auth_key=write_auth_key,
