@@ -39,7 +39,7 @@ AUTH_KEY = "watcher_admin_key"
 USER_ID_KEY = "kalavai_user_id"
 WRITE_AUTH_KEY = "watcher_write_key"
 ALLOW_UNREGISTERED_USER_KEY = "watcher_allow_unregistered_user"
-NODE_ROLE_LABEL = "kalavai.node_role"
+NODE_ROLE_LABEL = "kalavai/role"
 USER_API_KEY = "user_api_key"
 READONLY_AUTH_KEY = "watcher_readonly_key"
 WATCHER_SERVICE_KEY = "watcher_service"
@@ -159,15 +159,17 @@ def extract_auth_token(headers):
 def generate_compose_config(
     role,
     node_name,
-    mtu="1420",
+    mtu="",
     target_platform="amd64",
     write_to_file=True,
     node_ip_address="0.0.0.0",
+    lb_ip_address=None,
     num_gpus=0,
     node_labels=None,
     pool_ip=None,
     vpn_token=None,
-    pool_token=None
+    pool_token=None,
+    host_root_path=None,
 ):
     if node_labels is not None:
         node_labels = " ".join([f"--node-label {key}={value}" for key, value in node_labels.items()])
@@ -180,6 +182,7 @@ def generate_compose_config(
         "vpn_name": DEFAULT_VPN_CONTAINER_NAME,
         "mtu": mtu,
         "node_ip_address": node_ip_address,
+        "load_balancer_ip_address": lb_ip_address if lb_ip_address is not None else "",
         "pool_ip": pool_ip,
         "pool_token": pool_token,
         "vpn_token": vpn_token,
@@ -192,7 +195,8 @@ def generate_compose_config(
         "random_suffix": rand_suffix,
         "node_labels": node_labels,
         "flannel_iface": DEFAULT_FLANNEL_IFACE if vpn_token is not None else "",
-        "user_id": load_user_id()
+        "user_id": load_user_id(),
+        "host_root_path": host_root_path
     }
     # generate local config files
     compose_yaml = load_template(
